@@ -14,7 +14,7 @@ use Getopt::Long qw(:config no_auto_abbrev no_ignore_case);
 use Perl::Strip;
 use Pod::Usage 'pod2usage';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $IGNORE_FILE = [
     qr/\.pod$/,
@@ -272,19 +272,14 @@ That is, App::FatPacker::Simple only fatpacks a script with features:
 
 L<App::FatPacker>
 
-L<App::fatten>
+L<App::depak>
 
 L<Perl::Strip>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Shoichi Kaji.
+Copyright 2015 Shoichi Kaji E<lt>skaji@cpan.orgE<gt>
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-=head1 AUTHOR
-
-Shoichi Kaji E<lt>skaji@cpan.orgE<gt>
-
 =cut
-
